@@ -159,7 +159,7 @@ void AssetsAccount::writeAttributes(QXmlStreamAttributes *attr) {
 	Account::writeAttributes(attr);
 	if(o_currency) attr->append("currency", o_currency->code());
 	if(!isSecurities()) {
-		attr->append("initialbalance", QString::number(d_initbal, 'f', SAVE_MONETARY_DECIMAL_PLACES));
+		attr->append("initialbalance", QString::number(d_initbal, 'g', SAVE_MONETARY_PRECISION));
 		if(o_budget->budgetAccount == this) {
 			attr->append("budgetaccount", QString::number(o_budget->budgetAccount == this));
 		}
@@ -349,7 +349,7 @@ void CategoryAccount::writeElements(QXmlStreamWriter *xml) {
 	QMap<QDate, double>::const_iterator it_end = mbudgets.end();
 	for(QMap<QDate, double>::const_iterator it = mbudgets.begin(); it != it_end; ++it) {
 		xml->writeStartElement("budget");
-		xml->writeAttribute("value", QString::number(it.value(), 'f', SAVE_MONETARY_DECIMAL_PLACES));
+		xml->writeAttribute("value", QString::number(it.value(), 'g', SAVE_MONETARY_PRECISION));
 		xml->writeAttribute("date", it.key().toString(Qt::ISODate));
 		xml->writeEndElement();
 	}
