@@ -95,7 +95,9 @@ EditAssetsAccountDialog::EditAssetsAccountDialog(Budget *budg, QWidget *parent,
 	groupCombo->lineEdit()->setPlaceholderText(tr("no group"));
 	grid->addWidget(groupCombo, row, 1); row++;
 	if(!default_group.isEmpty()) groupCombo->setCurrentText(default_group);
+	else if(new_loan) groupCombo->setCurrentText(budget->getAccountTypeName(ASSETS_TYPE_LIABILITIES, true, true));
 	else if(default_type >= 0 && !budget->getAccountTypeName(default_type, true, true).isEmpty()) groupCombo->setCurrentText(budget->getAccountTypeName(default_type, true, true));
+	else groupCombo->setCurrentText(budget->getAccountTypeName(ASSETS_TYPE_CASH, true, true));
 
 	if(default_type >= 0) {
 		switch(default_type) {
@@ -119,6 +121,8 @@ EditAssetsAccountDialog::EditAssetsAccountDialog(Budget *budg, QWidget *parent,
 
 	grid->addWidget(new QLabel(tr("Name:"), this), row, 0);
 	nameEdit = new QLineEdit(this);
+	QFontMetrics fm(nameEdit->font());
+	nameEdit->setMinimumWidth(fm.averageCharWidth() * 25);
 	grid->addWidget(nameEdit, row, 1); row++;
 	maintainerLabel = new QLabel(tr("Bank:"));
 	grid->addWidget(maintainerLabel, row, 0);
@@ -420,6 +424,8 @@ EditIncomesAccountDialog::EditIncomesAccountDialog(Budget *budg, IncomesAccount
 	box1->addLayout(grid);
 	grid->addWidget(new QLabel(tr("Name:"), this), 0, 0);
 	nameEdit = new QLineEdit(this);
+	QFontMetrics fm(nameEdit->font());
+	nameEdit->setMinimumWidth(fm.averageCharWidth() * 25);
 	grid->addWidget(nameEdit, 0, 1);
 	grid->addWidget(new QLabel(tr("Parent category:"), this), 1, 0);
 	parentCombo = new QComboBox(this);
@@ -528,6 +534,8 @@ EditExpensesAccountDialog::EditExpensesAccountDialog(Budget *budg, ExpensesAccou
 	box1->addLayout(grid);
 	grid->addWidget(new QLabel(tr("Name:"), this), 0, 0);
 	nameEdit = new QLineEdit(this);
+	QFontMetrics fm(nameEdit->font());
+	nameEdit->setMinimumWidth(fm.averageCharWidth() * 25);
 	grid->addWidget(nameEdit, 0, 1);
 	grid->addWidget(new QLabel(tr("Parent category:"), this), 1, 0);
 	parentCombo = new QComboBox(this);
