@@ -76,12 +76,9 @@ int main(int argc, char **argv) {
 		}
 	}
 
+	setlocale(LC_ALL, "");
 	QString locale = setlocale(LC_MONETARY, NULL);
-	if(locale == QLocale::c().name()) {
-		setlocale(LC_MONETARY, QLocale::system().name().toLocal8Bit());
-	} else {
-		setlocale(LC_MONETARY, "");
-	}
+	if(locale == QLocale::c().name()) setlocale(LC_MONETARY, QLocale::system().name().toLocal8Bit());
 
 	QString slang = settings.value("language", QString()).toString();
 
